'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const stylable_1 = require("stylable");
const provider_1 = require("./provider");
function createProvider(stylable, tsLangService) {
    return new provider_1.default(stylable, tsLangService);
}
exports.createProvider = createProvider;
let legacyBehvior = true;
function toggleLegacy(value) {
    legacyBehvior = value;
}
exports.toggleLegacy = toggleLegacy;
function createFs(fileSystem) {
    return {
        readFileSync(path) {
            return fileSystem.loadTextFileSync(path).toString();
        },
        statSync(path) {
            let simpleStats;
            try {
                simpleStats = fileSystem.statSync(path);
            }
            catch (_a) {
                // TODO: remove this, it's for supporting bad tests ('should create basic diagnostics' et al) where the file to process is not from the file system
                simpleStats = { type: 'dir' };
            }
            return {
                isDirectory() {
                    return simpleStats.type === 'dir';
                },
                isFile() {
                    return simpleStats.type === 'file';
                },
                mtime: new Date(Date.now())
            };
        },
        readlinkSync(_path) {
            return null;
        }
    };
}
exports.createFs = createFs;
function createProcessor(fileSystem) {
    let proccesor = stylable_1.cachedProcessFile((fullpath, content) => {
        return stylable_1.process(stylable_1.safeParse(content, { from: fullpath }));
    }, createFs(fileSystem));
    return proccesor;
}
exports.createProcessor = createProcessor;
//# sourceMappingURL=provider-factory.js.map